# We are on github! [Console_images](https://github.com/LedinecMing/console_images)
This is a lib of making images ascii and colored  
# console_images
Console images in 48 colors, 216 colors and full rgb  
# Full RGB
![Full rgb](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/full_rgb.png)  
# 216 colors
![216 colors](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/216%20colors.png)  
# 48 colors
![48 colors](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/48%20colors.jpeg)  
If it does not work maybe you should change color_function to color_it48 or color_it216 (maybe you use windows)

Console color schemes:  
[216 colors](https://robotmoon.com/256-colors/)  
[Full RGB](https://gist.github.com/XVilka/8346728)
# Color circles
![Full RGB](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/color-circle.png)
![216](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/color-circle1.png)
![48](https://raw.githubusercontent.com/LedinecMing/console_images/main/examples/color-circle2.png)
